/***************************************************************/
/*                                                             */
/*      PROJECT NAME :  RL78G10_mDriver                        */
/*      FILE         :  RL78G10_mDriver.c                      */
/*      DESCRIPTION  :  Main Program                           */
/*      CPU SERIES   :  RL78 - G10                             */
/*      CPU TYPE     :  R5F10Y16                               */
/*                                                             */
/*      This file is generated by e2 studio.                   */
/*                                                             */
/***************************************************************/                                   
                                                                                            
                                                                                            
/************************************************************************/
/*    File Version: V1.00                                               */
/*    Date Generated: 10/09/2013                                        */
/************************************************************************/

#include "typedefine.h"
#include "iodefine.h"
#include "iodefine_ext.h"
#include "drv_uart.h"
#include "drv_timer.h"

#define _0X25_ADC_SAU_TAU_ENABLE	(0x25)

typedef enum {
	MOTOR_FREE = 0x00,
	MOTOR_CW,
	MOTOR_CCW,
	MOTOR_BRAKE
} MOTOR_STATE;

uint16_t adcData;
MOTOR_STATE mState;
uint8_t pwmH;
uint8_t pwmL;

void drv_portInit(void)
{
	PMC0 = 0xE5;
    P0 = 1;
	PM0 = 0xE6;
	PM4 = 0xFE;
	P4 = 0xFE;
	PMK0 = 0;
	EGN0 = 1;
	ADM0 = 0x09;
	ADS = 0x01;	//ANI1 SEL
	ADMK = 0;	//ADMK INT EN
}

void mtPortChenge(MOTOR_STATE rot)
{
	R_TAU0_Channel0_Stop();

    TDR01H = pwmH;
    TDR01L = pwmL;

	switch(rot){
	case MOTOR_FREE:
        TDR01H = 0;
        TDR01L = 0;
		P0 &= 0xEF;
		P4 = 0;
		R_TAU0_Channel0_Start();
		break;
	case MOTOR_CW:
		PIOR &= 0xFD;
		P0 &= 0xEF;
		P4 = 0x00;
		R_TAU0_Channel0_Start();
		break;
	case MOTOR_CCW:
		PIOR |= 0x02;
		P0 &= 0xEF;
		P4 = 0x00;
		R_TAU0_Channel0_Start();
		break;
	case MOTOR_BRAKE:
		P0 |= 0x10;
		P4 = 0x01;
		break;
	default:
		return;
	}
	mState = rot;
}

void systemInit(void)
{
	EI();
	PER0 = _0X25_ADC_SAU_TAU_ENABLE;
	drv_portInit();
	R_SAU0_Create();
	R_TAU0_Create();
	mtPortChenge(MOTOR_FREE);
}

void main(void)
{
    // TODO: add application code here
	UART_CMD uartData;
	uint16_t data;

	systemInit();
    while (1)
    {
    	uartCMD_Receive(&uartData);
        switch(uartData.uartCMD){
        case CMD_GET_ADC:
            ADCS = 1;
            break;
        case CMD_SET_MT_STATE:
        	mtPortChenge(uartData.uartData[0]);
        case CMD_PING:
            drv_uartSend(uartData.uartCMD,0x0000);
        	break;
        case CMD_GET_MT_STATE:
            drv_uartSend(uartData.uartCMD,(uint16_t)mState);
        	break;
        case CMD_SET_FREQ:
        	R_TAU0_Channel0_Stop();
            TDR00H = uartData.uartData[1];
            TDR00L = uartData.uartData[0];
    		R_TAU0_Channel0_Start();
       case CMD_GET_FREQ:
            data = (uint16_t)(TDR00L) | (uint16_t)(TDR00H<<8);
            drv_uartSend(uartData.uartCMD,data);
        	break;
        case CMD_SET_DUTY:
        	R_TAU0_Channel0_Stop();
        	if(mState != MOTOR_FREE)
        	{
                TDR01H = uartData.uartData[1];
                TDR01L = uartData.uartData[0];
        	}
            pwmL = uartData.uartData[0];
            pwmH = uartData.uartData[1];
    		R_TAU0_Channel0_Start();
        case CMD_GET_DUTY:
            data = (uint16_t)(pwmL) | (uint16_t)(pwmH<<8);
            drv_uartSend(uartData.uartCMD,data);
         default:
        	break;
        }
    }
}
